pub struct AnchorNone;Trait Implementations
Sourceimpl Anchor for AnchorNone
impl Anchor for AnchorNone
Sourcefn assert<'a, H: Haystack<'a>>(_hay: &H) -> ControlFlow<(), bool>
fn assert<'a, H: Haystack<'a>>(_hay: &H) -> ControlFlow<(), bool>
Asserts that each anchor in this set could possibly succeed with the given haystack state.
In the presence of a start anchor, the haystack’s position at the start doesn’t need to be
checked again. Read more
Sourcefn assert_fixed<'a, H: Haystack<'a>>(_hay: &H) -> bool
fn assert_fixed<'a, H: Haystack<'a>>(_hay: &H) -> bool
Asserts that each anchor in this set could possibly succeed with the given haystack state.
In the presence of a start anchor, the haystack’s position at the start doesn’t need to be
checked again. This variant provide no information about whether the search should continue
and should be called by searches that intend to match the entirety of the provided haystack.
Sourceimpl Clone for AnchorNone
impl Clone for AnchorNone
Sourcefn clone(&self) -> AnchorNone
fn clone(&self) -> AnchorNone
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnchorNone
impl Debug for AnchorNone
Sourceimpl Default for AnchorNone
impl Default for AnchorNone
Sourcefn default() -> AnchorNone
fn default() -> AnchorNone
Returns the “default value” for a type. Read more
impl Copy for AnchorNone