pub struct AnchorPair<A: Anchor, B: Anchor>(pub PhantomData<(A, B)>);Tuple Fields
0: PhantomData<(A, B)>Trait Implementations
Sourceimpl<A: Anchor, B: Anchor> Anchor for AnchorPair<A, B>
impl<A: Anchor, B: Anchor> Anchor for AnchorPair<A, B>
Sourcefn assert<'a, H: Haystack<'a>>(hay: &H) -> ControlFlow<(), bool>
fn assert<'a, H: Haystack<'a>>(hay: &H) -> ControlFlow<(), bool>
Asserts that each anchor in this set could possibly succeed with the given haystack state.
In the presence of a start anchor, the haystack’s position at the start doesn’t need to be
checked again. Read more
Sourcefn assert_fixed<'a, H: Haystack<'a>>(hay: &H) -> bool
fn assert_fixed<'a, H: Haystack<'a>>(hay: &H) -> bool
Asserts that each anchor in this set could possibly succeed with the given haystack state.
In the presence of a start anchor, the haystack’s position at the start doesn’t need to be
checked again. This variant provide no information about whether the search should continue
and should be called by searches that intend to match the entirety of the provided haystack.
Sourceimpl<A: Clone + Anchor, B: Clone + Anchor> Clone for AnchorPair<A, B>
impl<A: Clone + Anchor, B: Clone + Anchor> Clone for AnchorPair<A, B>
Sourcefn clone(&self) -> AnchorPair<A, B>
fn clone(&self) -> AnchorPair<A, B>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<A: Default + Anchor, B: Default + Anchor> Default for AnchorPair<A, B>
impl<A: Default + Anchor, B: Default + Anchor> Default for AnchorPair<A, B>
Sourcefn default() -> AnchorPair<A, B>
fn default() -> AnchorPair<A, B>
Returns the “default value” for a type. Read more
impl<A: Copy + Anchor, B: Copy + Anchor> Copy for AnchorPair<A, B>