pub struct AnchorSet<A: Anchor, B: Anchor, C: Anchor>(pub PhantomData<(A, B, C)>);Tuple Fields
0: PhantomData<(A, B, C)>Trait Implementations
Sourceimpl<A: Anchor, B: Anchor, C: Anchor> Anchor for AnchorSet<A, B, C>
impl<A: Anchor, B: Anchor, C: Anchor> Anchor for AnchorSet<A, B, C>
Sourcefn assert<'a, H: Haystack<'a>>(hay: &H) -> ControlFlow<(), bool>
fn assert<'a, H: Haystack<'a>>(hay: &H) -> ControlFlow<(), bool>
Asserts that each anchor in this set could possibly succeed with the given haystack state.
In the presence of a start anchor, the haystack’s position at the start doesn’t need to be
checked again. Read more
Sourcefn assert_fixed<'a, H: Haystack<'a>>(hay: &H) -> bool
fn assert_fixed<'a, H: Haystack<'a>>(hay: &H) -> bool
Asserts that each anchor in this set could possibly succeed with the given haystack state.
In the presence of a start anchor, the haystack’s position at the start doesn’t need to be
checked again. This variant provide no information about whether the search should continue
and should be called by searches that intend to match the entirety of the provided haystack.
Sourceimpl<A: Default + Anchor, B: Default + Anchor, C: Default + Anchor> Default for AnchorSet<A, B, C>
impl<A: Default + Anchor, B: Default + Anchor, C: Default + Anchor> Default for AnchorSet<A, B, C>
impl<A: Copy + Anchor, B: Copy + Anchor, C: Copy + Anchor> Copy for AnchorSet<A, B, C>