pub struct EndAndMaxLen<const N: usize>;Trait Implementations
Sourceimpl<const N: usize> Anchor for EndAndMaxLen<N>
impl<const N: usize> Anchor for EndAndMaxLen<N>
Sourcefn assert<'a, H: Haystack<'a>>(hay: &H) -> ControlFlow<(), bool>
fn assert<'a, H: Haystack<'a>>(hay: &H) -> ControlFlow<(), bool>
Asserts that each anchor in this set could possibly succeed with the given haystack state.
In the presence of a start anchor, the haystack’s position at the start doesn’t need to be
checked again. Read more
Sourcefn assert_fixed<'a, H: Haystack<'a>>(hay: &H) -> bool
fn assert_fixed<'a, H: Haystack<'a>>(hay: &H) -> bool
Asserts that each anchor in this set could possibly succeed with the given haystack state.
In the presence of a start anchor, the haystack’s position at the start doesn’t need to be
checked again. This variant provide no information about whether the search should continue
and should be called by searches that intend to match the entirety of the provided haystack.
Sourceimpl<const N: usize> Clone for EndAndMaxLen<N>
impl<const N: usize> Clone for EndAndMaxLen<N>
Sourcefn clone(&self) -> EndAndMaxLen<N>
fn clone(&self) -> EndAndMaxLen<N>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<const N: usize> Debug for EndAndMaxLen<N>
impl<const N: usize> Debug for EndAndMaxLen<N>
Sourceimpl<const N: usize> Default for EndAndMaxLen<N>
impl<const N: usize> Default for EndAndMaxLen<N>
Sourcefn default() -> EndAndMaxLen<N>
fn default() -> EndAndMaxLen<N>
Returns the “default value” for a type. Read more
impl<const N: usize> Copy for EndAndMaxLen<N>