pub struct Start;Trait Implementations
Sourceimpl Anchor for Start
impl Anchor for Start
Sourcefn assert<'a, H: Haystack<'a>>(hay: &H) -> ControlFlow<(), bool>
fn assert<'a, H: Haystack<'a>>(hay: &H) -> ControlFlow<(), bool>
Asserts that each anchor in this set could possibly succeed with the given haystack state.
In the presence of a start anchor, the haystack’s position at the start doesn’t need to be
checked again. Read more
Sourcefn assert_fixed<'a, H: Haystack<'a>>(_hay: &H) -> bool
fn assert_fixed<'a, H: Haystack<'a>>(_hay: &H) -> bool
Asserts that each anchor in this set could possibly succeed with the given haystack state.
In the presence of a start anchor, the haystack’s position at the start doesn’t need to be
checked again. This variant provide no information about whether the search should continue
and should be called by searches that intend to match the entirety of the provided haystack.
impl Copy for Start